/**
 * Copyright (C) 2003-2005 Funambol
 *
 *This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


package sync4j.server.admin.ws;

import java.io.*;
import java.lang.Class;
import java.lang.ClassLoader;
import java.util.logging.Logger;
import java.util.logging.Level;

import javax.servlet.*;
import javax.servlet.http.*;

import sync4j.framework.logging.Sync4jLogger;


/**
 * This servlet allows the downloading of a class as found by the servlet's
 * class loader. It can be used to remotely download classes deployed on the 
 * server.
 * <p>
 * It accepts the following parameters:
 * <table>
 * <tr>
 * <td>class</td>
 * <td>the class to download in the dotted or slashed form and optionally ended
 *     by .class</td>
 * </tr>
 * </table>
 *
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: ClassDownloadServlet.java,v 1.3 2005/03/02 20:57:39 harrie Exp $
 *
 */
public final class ClassDownloadServlet 
extends javax.servlet.http.HttpServlet {

    // --------------------------------------------------------------- Constants

    public static final String LOG_NAME = "server";

    // ------------------------------------------------------------ Private data

    private Logger log = Sync4jLogger.getLogger(LOG_NAME);

    // ---------------------------------------------------------- Public methods

    public void service(final HttpServletRequest  request,
                        final HttpServletResponse response)
    throws ServletException, IOException {
        if (log.isLoggable(Level.FINEST)) {
            log.finest(request.toString());
            log.finest(request.getRequestURI());
        }
        
        String className = request.getPathInfo();
        
        if (className == null) {
            className = "";
        } else {
            //
            // skip the initial '/'
            //
            className = className.substring(1);
        }
        
        if (log.isLoggable(Level.FINEST)) {
            log.finest("Requesting class: " + className);
        }
        
        //
        // First of all normalize the class name in order to be retrieved
        // by getResourceAsStream()
        //
        className = className.trim();
        if (className.endsWith(".class")) {
            int l = className.length();
            
            if (l>6) {
                className = className.substring(0, l-6);
            } else {
                className = "";
            }
        }
        className = className.replace('.', '/');
        className = className + ".class";
        
        if (log.isLoggable(Level.FINEST)) {
            log.finest("Looking for class: " + className);
        }
        
        ClassLoader cl = this.getClass().getClassLoader();
        
        InputStream is = cl.getResourceAsStream(className);
        
        if (is == null) {
            //
            // Class not found!
            //
            response.sendError(response.SC_NOT_FOUND, className + " not found");
            return;
        }
        
        byte[] buf = new byte[4096];
        int i = 0;
        OutputStream os = null;
        try {
            os = response.getOutputStream();
            
            while ((i = is.read(buf)) > 0) {
                os.write(buf, 0, i);
            }
        } catch (IOException e) {
            log.severe(e.getMessage());
            log.throwing(getClass().getName(), "service", e);
        } finally {
            if (os != null) {
                os.close();
            }
            is.close();
        }
    }

    // --------------------------------------------------------- Private methods
}


