/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package sync4j.server.store;

import java.util.Map;
import java.util.HashMap;
import java.util.Iterator;

import java.sql.*;

import sync4j.framework.tools.DBTools;

import sync4j.framework.server.LastTimestamp;
import sync4j.framework.server.store.Clause;
import sync4j.framework.server.store.PersistentStore;
import sync4j.framework.server.store.BasePersistentStore;
import sync4j.framework.server.store.NotFoundException;
import sync4j.framework.server.store.PersistentStoreException;
import sync4j.framework.server.ID;

/**
 * This is the store for persistent information regarding ID
 * It persists the following classes:
 * <ul>
 * <li>sync4j.framework.server.GUID</li>
 * </ul>
 *
 * @version $Id: IDPersistentStore.java,v 1.1 2005/07/25 15:27:36 nichele Exp $
 */
public class IDPersistentStore extends BasePersistentStore
    implements PersistentStore, java.io.Serializable {

    // --------------------------------------------------------------- Constants

    public static final int SQL_GET_ID    = 0;
    public static final int SQL_UPDATE_ID = 1;

    // -------------------------------------------------------------- Properties

    protected String[] sql = null;

    public void setSql(String[] sql) {
        this.sql = sql;
    }

    public String[] getSql() {
        return this.sql;
    }


    // ------------------------------------------------------------ Constructors
    // ---------------------------------------------------------- Public methods

    public boolean delete(Object o) throws PersistentStoreException {
        return false;
    }

    public boolean store(Object o, String operation) throws PersistentStoreException {
        return false;
    }

    /**
    * Store the given ID.
    *
    * @param o the Object that must be a ID object
    * @throws PersistentStoreException
    */
    public boolean store(Object o) throws PersistentStoreException {
        if (o instanceof ID) {

            ID id = (ID) o;
            String idSpace = id.getIdSpace();
            int counter    = id.getValue();

            if (idSpace == null) {
                throw new PersistentStoreException("Id space must be not null");
            }

            Connection conn        = null;
            PreparedStatement stmt = null;
            ResultSet rs           = null;

            try {
                conn = dataSource.getConnection();

                stmt = conn.prepareStatement(sql[SQL_UPDATE_ID]);
                stmt.setInt   (1, counter);
                stmt.setString(2, idSpace);
                stmt.executeUpdate();

            } catch (SQLException e) {
                e.printStackTrace();
                throw new PersistentStoreException("Error storing the counter " + idSpace, e);
            } finally {
                DBTools.close(conn, stmt, rs);
            }

            return true;
        }
        return false;

    }

    /**
     * Read the id from the data store.
     * @param o The object that must be a ID for this method
     * @throws PersistentException in case of error reading the data store
     */
    public boolean read(Object o) throws PersistentStoreException {
        if (o instanceof ID) {

            ID id = (ID) o;
            String idSpace = id.getIdSpace();

            if (idSpace == null) {
                throw new PersistentStoreException("Id space must be not null");
            }

            Connection conn        = null;
            PreparedStatement stmt = null;
            ResultSet rs           = null;

            try {
                conn = dataSource.getConnection();

                int counter = 0;

                stmt = conn.prepareStatement(sql[SQL_GET_ID]);
                stmt.setString(1, id.getIdSpace());
                rs = stmt.executeQuery();

                if (rs.next() == false) {
                    throw new NotFoundException("Counter not found for "
                                                + idSpace);
                }

                counter = rs.getInt(1) + 1;

                DBTools.close(null, stmt, rs);

                stmt = conn.prepareStatement(sql[SQL_UPDATE_ID]);
                stmt.setInt   (1, counter);
                stmt.setString(2, idSpace);
                stmt.executeUpdate();

                id.setValue(counter);

            } catch (SQLException e) {
                e.printStackTrace();
                throw new PersistentStoreException("Error reading the counter " + idSpace, e);
            } finally {
                DBTools.close(conn, stmt, rs);
            }

            return true;
        }
        return false;
    }

    public Object[] read(Class objClass) throws PersistentStoreException {
        return null;
    }

    public Object[] read(Object o, Clause clause) throws PersistentStoreException {
        return new Object[0];
    }

    public int count(Object o, Clause clause) throws PersistentStoreException {
        return 0;
    }

}

