--
-- This script contains the ddl to create the engine database.
--
-- @version $Id: create_engine.ddl,v 1.31 2005/10/26 10:41:17 luigiafassina Exp $
--

create table sync4j_principal
(
  username varchar(32)  BINARY NOT NULL,
  device   varchar(128) BINARY NOT NULL,
  id       integer      NOT NULL,
  
  constraint pk_sync4j_principal primary key (id)
);

create table sync4j_user
(
  username   varchar(32)  BINARY NOT NULL,
  password   varchar(32)  BINARY NOT NULL,
  email      varchar(50)  BINARY,
  first_name varchar(255) BINARY,
  last_name  varchar(255) BINARY,
  
  constraint pk_sync4j_user primary key (username)
);

create table sync4j_device
(
  id              varchar(128) BINARY NOT NULL,
  description     varchar(255) BINARY,
  type            varchar(255) BINARY,
  client_nonce    varchar(255) BINARY,
  server_nonce    varchar(255) BINARY,
  server_password varchar(255) BINARY,
  id_caps         integer NOT NULL default '2',
  timezone        varchar(50)  BINARY,  
  convert_date    char   (1)         ,
  charset         varchar(50)  BINARY,    
  
  constraint pk_sync4j_device primary key (id)
);

create table sync4j_device_caps
(
  id              integer NOT NULL,
  largeobject     char(1) NOT NULL default 'N',
  numberofchanges char(1) NOT NULL default 'N',
  
  constraint pk_sync4j_device_caps primary key (id)
);

create table sync4j_sync_source
(
  uri        varchar(40)  BINARY NOT NULL,
  config     varchar(255) BINARY NOT NULL,
  name       varchar(200) BINARY NOT NULL,
  sourcetype varchar(128) BINARY NOT NULL,
  
  constraint pk_sync4j_sync_source primary key (uri)
);

create table sync4j_last_sync
(
  principal          integer NOT NULL,
  sync_source        varchar(40) BINARY NOT NULL,
  last_anchor_server varchar(20) BINARY,
  last_anchor_client varchar(20) BINARY,
  start_sync         datetime,
  end_sync           datetime,
  
  constraint pk_sync4j_last_sync primary key (principal, sync_source)
);

create table sync4j_client_mapping
(
  principal   integer NOT NULL,
  sync_source varchar(32 ) BINARY NOT NULL,
  luid        varchar(150) BINARY NOT NULL,
  guid        varchar(150) BINARY NOT NULL,
  
  constraint pk_clientmapping primary key (principal, sync_source, luid, guid)
);

create table sync4j_id
(
  idspace varchar(30) BINARY NOT NULL,
  counter int         NOT NULL,
  
  constraint pk_sync4j_id primary key (idspace)
);

create table sync4j_module
(
  id          varchar(128) BINARY NOT NULL,
  name        varchar(200) BINARY NOT NULL,
  description varchar(200) BINARY,
  
  constraint pk_sync4j_module primary key (id)
);

create table sync4j_sync_source_type
(
  id           varchar(128) BINARY NOT NULL,
  description  varchar(200) BINARY,
  class        varchar(255) BINARY NOT NULL,
  admin_class  varchar(255) BINARY,
  
  constraint pk_sync4j_sst primary key (id)
);

create table sync4j_module_sync_source_type
(
  module     varchar(128) BINARY NOT NULL,
  sourcetype varchar(128) BINARY NOT NULL,
  
  constraint pk_sync4j_msst primary key (module, sourcetype)
);

create table sync4j_connector
(
  id            varchar(128) BINARY NOT NULL,
  name          varchar(200) BINARY NOT NULL,
  description   varchar(200) BINARY,
  admin_class   varchar(255) BINARY,
    
  constraint pk_sync4j_connector primary key (id)
);

create table sync4j_module_connector
(
  module      varchar(128) BINARY NOT NULL,
  connector   varchar(128) BINARY NOT NULL,
    
  constraint pk_sync4j_module_connector primary key (module, connector)
);

create table sync4j_connector_source_type
(
  connector  varchar(128) BINARY NOT NULL,
  sourcetype varchar(128) BINARY NOT NULL,
  
  constraint pk_sync4j_connector_sst primary key (connector, sourcetype)
);

create table sync4j_role
(
  role        varchar(128) BINARY NOT NULL,
  description varchar(200) BINARY NOT NULL,
 
  constraint pk_sync4j_role primary key (role)
);

create table sync4j_user_role
(
  username varchar(32 ) BINARY NOT NULL,
  role     varchar(128) BINARY NOT NULL,
 
  constraint pk_sync4j_user_role primary key (username,role)
);


alter table sync4j_principal add constraint fk_user foreign key (
  username
)
references sync4j_user (
  username
) ON DELETE CASCADE;

alter table sync4j_principal add constraint fk_device foreign key (
  device
)
references sync4j_device (
  id
) ON DELETE CASCADE;

alter table sync4j_last_sync add constraint fk_principal foreign key (
  principal
)
references sync4j_principal (
  id
) ON DELETE CASCADE;

alter table sync4j_last_sync add constraint fk_source foreign key (
  sync_source
)
references sync4j_sync_source (
  uri
) ON DELETE CASCADE;

alter table sync4j_client_mapping add constraint fk_principal1 foreign key (
  principal
)
references sync4j_principal (
  id
) ON DELETE CASCADE;

alter table sync4j_client_mapping add constraint fk_source1 foreign key (
  sync_source
)
references sync4j_sync_source (
  uri
) ON DELETE CASCADE;

alter table sync4j_device add constraint fk_device_caps foreign key (
  id_caps
)
references sync4j_device_caps (
  id
) ON DELETE CASCADE;

create index ind_principal on sync4j_principal (username, device);
create index ind_user      on sync4j_user      (username, password);